#
# spec file for package perl-GraphViz
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name GraphViz
Name:           perl-GraphViz
Version:        2.26
Release:        1.8
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Interface to AT&T's GraphViz. Deprecated. See GraphViz2
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETJ/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which) >= 1.09
BuildRequires:  perl(IPC::Run) >= 0.6
BuildRequires:  perl(LWP::Simple) >= 6
BuildRequires:  perl(Parse::RecDescent) >= 1.965001
BuildRequires:  perl(Test::More) >= 1.001002
BuildRequires:  perl(XML::Twig) >= 3.52
BuildRequires:  perl(XML::XPath) >= 1.13
Requires:       perl(File::Which) >= 1.09
Requires:       perl(IPC::Run) >= 0.6
Requires:       perl(LWP::Simple) >= 6
Requires:       perl(Parse::RecDescent) >= 1.965001
Requires:       perl(XML::Twig) >= 3.52
Requires:       perl(XML::XPath) >= 1.13
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  graphviz
# graphviz-gnome is required so that dot -Tpng works.
Requires:       cairo
Requires:       graphviz
Requires:       graphviz-gnome
Requires:       pango
# MANUAL END

%description
This module provides an interface to layout and image generation of
directed and undirected graphs in a variety of formats (PostScript, PNG,
etc.) using the "dot", "neato", "twopi", "circo" and "fdp" programs from
the Graphviz project (http://www.graphviz.org/ or
http://www.research.att.com/sw/tools/graphviz/).

GraphViz is deprecated in favour of GraphViz2.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
sed -i -e s,/usr/local/bin/perl,/usr/bin/perl, examples/*.pl
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README
%license LICENSE

%changelog
* Sat Mar  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.26
  see /usr/share/doc/packages/perl-GraphViz/Changes
  2.26 2023-03-03
  - unchanged from 2.25 (except for deps adjustment) which also got deleted from CPAN by co-maint
* Mon Aug 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.25
  see /usr/share/doc/packages/perl-GraphViz/Changes
* Fri Oct 13 2017 coolo@suse.com
- updated to 2.24
  - Test with Test::More V 1.001002 rather than V 1.302019, and all tests still pass.
    See RT#115236. Thanx to Kent Fredric for again (sorry!) prompting me over this.
    Lowering the version of Test::More in Makefile.PL is the only change in this version.
  - Add no_xxe to XML::Twig instantiation. See RT#118972. Many thanx to Lisa Hare for a
    very well-crafted set of patches provided via github.
  - Revert change so we use Test::More instead of Test2::Bundle::Extended.
    See RT#115236. Thanx to ribasushi for this report, and my apologies for not acting sooner.
  - Escape a '{' in a regexp in t/foo.t. See RT#114551. Thanx to Slaven Rezic.
  - Fix a typo in a comment, as provided by Gregor Herrmann in RT#111385.
  - See http://savage.net.au/Ron/html/My.Workflow.for.Building.Distros.html for notes on the
    modernization of the repo.
    This includes updating Makefile.PL and removing Build.PL, MANIFEST and *META.*.
  - Bail out cleanly if 'dot' is not installed. See RT#105575. Thanx Karen Etheridge.
  - Update docs to point to a copy of the Perl licence.
  - Update docs in GraphViz.pm to point to the github repo.
  - Move t/pod.t into xt/author/.
  - Merge patch from ntyni via github. This concerned use of defined(@some_array). With thanx.
  - Accept pull request from Patrice Clement to add the x_deprecated flag to both META.json and
    META.yml. The docs already had various references to 'deprecated', including directing users
    to GraphViz2, so no change is needed there. Thanx Patrice.
  - Add .gitignore to MANIFEST.SKIP.
  - All patches to this version are from chrony, via a github pull request. With thanx.
  - Use File::Which on Windows to detect if Graphviz is present.
  - Clean up the code, including Build.PL and Makefile.PL.
* Mon May 12 2014 vcizek@suse.com
- update to 2.15
  * fixes build on Factory
  * changes:
  - Fix double-quote escaping bug in GraphViz's _attributes() method. See RT#90528.
  - Patch t/foo.t to not assume text appears on specific lines of the output test files.
  - Re-package distro because users get errors during testing. See RT#80709.
  - For pre-reqs such as strict, warnings, etc, which ship with Perl, set the version # to 0.
  Reported as RT#80663 by Father Chrysostomos for Tree::DAG_Node.
  - Add VDX as an output format.
  - Accept a patch kindly supplied by Alexander Kriegisch, to change handling of the rankdir attribute.
  - Patch this file to replace BST with GMT, since both DateTime::Format::HTTP and DateTime::Format::Strptime
* Fri Nov 18 2011 coolo@suse.com
- update to 2.08
  - Wind back pre-reqs for various modules to match what was shipped with Perl V 5.8.1.
    Many thanx to Brian Cassidy for the error report: https://rt.cpan.org/Ticket/Display.html?id=72068.
  - Rewrite Build.PL and Makefile.PL to try loading File::Which rather than assuming it is installed.
    This avoids the chicken-and-egg problem whereby these 2 programs need File::Which::which to find 'dot'.
    Many thanx to Richard Clamp for the error report: https://rt.cpan.org/Public/Bug/Display.html?id=71971.
  - Add File::Which to the pre-reqs in Build.PL and Makefile.PL.
  - Add 'Deprecated. See GraphViz2' to the docs.
  - Add Build.PL.
  - Add ability to set ORIENTATION. Thanx to Christian Lackas for the patch. See RT#71787.
  - Add Changelog.ini.
  - Add META.json, MYMETA.json and MYMETA.yml.
  - Add MANIFEST.SKIP.
  - Ensure all modules contain a version number.
  - Update the docs regarding the list of modules shipped in this distro.
  - Remove examples/remote.pl because GraphViz::Remote is no longer shipped.
  - Clean up examples/clusters2.pl.
  - Clean up Makefile.PL.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Oct 13 2010 jw@novell.com
- graphviz-gnome is required so that dot -Tpng works.
* Fri Jul 30 2010 kai.blin@biotech.uni-tuebingen.de
- initial package 2.04
  * created by cpanspec 1.78
